#!/bin/zsh --no-rcs

echo "<html><body>"


echo "<style>"
echo "pre {"
echo "font-family: Consolas, Courier, monospace;"
echo "white-space: pre-wrap;"
echo "tab-size: 4;"
echo "background: #D3D3D3;"
echo "color: black;"
echo "padding:20px;"
echo "border-radius: 5px;"
echo "}"
echo "</style>"

echo "<img src=\"icon.png\" style=\"float: right;\">"

# Check for Alfred being installed - it really should be if they are running this script
# But for completeness and in case I have to ask someone to run it standalone.
echo "<h1>Alfred</h1>"
echo "<p>The Conductor workflow for Alfred is for controlling the Keyboard Maestro app. Alfred is a foundational pre-requisite, and Alfred version 5 must be available.</p>"
if [ -d "/Applications/Alfred 5.app" ]
then
	echo "<p style=\"color:green\">&check; Alfred 5 is installed.</p>"
else
	echo "<p style=\"color:red\">&cross; We cannot find an installation of the Alfred 5 app.</p>"
	echo "<p>Please install <a href=\"https://www.alfredapp.com\">the Alfred app from Alfred App's website</a>.</p>"
fi

echo "<p>Conductor is a custom Alfred workflow. To run it, you <strong>must</strong> have a valid <a href=\"https://www.alfredapp.com/powerpack/\">Alfred Power Pack license</a> in place.</p>"

cd "$HOME/Library/Application Support/Alfred"
alfredPowerPackFile=$(ls powerpack.*.dat) 2>/dev/null
if [ "$alfredPowerPackFile" = "" ]
then
	echo "<p style=\"color:red\">&cross; We cannot find the Alfred Power Pack license information.</p>"
else
	echo "<p style=\"color:green\">&check; Alfred Power Pack information identified (Version $(cut -c2-2 < "$alfredPowerPackFile")).</p>"
fi

echo "<h2>Conductor Workflow</h2>"
echo "<p>"
echo -n "<strong>Installed Version:</strong> "
echo $alfred_workflow_version
#echo "<br>"
#echo -n "<strong>Latest Available Version:</strong> "
#curl -s https://tbc.thoughtasylum.com/latestversion.txt
echo "</p>"

# Check for Keyboard Maestro being installed
echo "<h1>Keyboard Maestro</h1>"
echo "<p>The Conductor workflow for Alfred is for interacting with the Keyboard Maestro app. Keyboard Maestro is therefore a pre-requisite.</p>"
if [ -d "/Applications/Keyboard Maestro.app" ]
then
	echo "<p style=\"color:green\">&check; Keyboard Maestro is installed.</p>"
	
	#Initialise Drafts Information variables
	KMV=$(defaults read "/Applications/Keyboard Maestro.app/Contents/Info" CFBundleVersion)
	PN=$(sw_vers -productName)
	PV=$(sw_vers -productVersion)
	BV=$(sw_vers -buildVersion)
	
	echo "<ul>"
	echo "	<li>Keyboard Maestro Version: $KMV</li>"
	echo "	<li>OS Version: $PN, $PV ($BV)</li>"
	echo "</ul>"

else
	echo "<p style=\"color:red\">&cross; We cannot find an installation of the Keyboard Maestro app.</p>"
	echo "<p>Please install <a href=\"https://keyboardmaestro.com\">the Keyboard Maestro app</a>.</p>"
fi


# Gather Python information for the Alfred session
# Python2 version seems to go to stderr, stdout
p2=$(python2 --version 2>&1)
p3=$(python3 --version)
pd=$(python --version)

# Output Python Information
echo "<h1>Python</h1>"
echo "<p>Doctor Drafts uses Python 3 for some of the more advanced interaction  features. While you can still use many fgeatures without it, we strongly recommend having Python 3 available in order to access the full power of Doctor Drafts.</p>"
echo "<p>To make use of Python 3, it must be installed and be found in your \$PATH environment variable, so that Doctor Drafts knows where to find it.</p>"
echo
echo "<p>We found the following Python versions available:</p>"
echo 
echo "<ul>"
echo "<li>Python 3: $p3</li>"
echo "<li>Python 2: $p2</li>"
echo "<li>Python (Default): $pd</li>"
echo "</ul>"
echo

# Check the length of the Python 3 version string
if [[ -n "$p3" ]]
then
	echo "<p style=\"color:green\">&check; Alfred can find a Python 3 installation.</p>"
else
	echo "<p style=\"color:red\">&cross; Alfred cannot find a Python 3 installation.</p>"
	echo "<p>Please read <a href=\"https://doctordrafts.thoughtasylum.com/basic/installation/\">how to install Python 3 for use with Doctor Drafts</a>.</p>"
fi

echo
echo "<h1>PATH Variable</h1>"
echo "<p>Your \$PATH variable paths are as follows:</p>"
echo
echo "<pre>"
# Substitute the path delimiters with newlines
echo -e ${PATH:gs/\:/\\n/}
echo "</pre>"


echo
echo "<h1>PATH Variable</h1>"
echo "<p>Your \$PATH variable paths are as follows:</p>"
echo
echo "<pre>"
# Substitute the path delimiters with newlines
echo -e ${PATH:gs/\:/\\n/}
echo "</pre>"


echo
echo "<h1>.zshenv Content</h1>"
echo "<p>Your ZSH Environment file content is as follows:</p>"
echo
echo "<pre>"
cat "$HOME/.zshenv"
echo "</pre>"

echo
echo "<h1>.zprofile Content</h1>"
echo "<p>Your ZSH Profile file content is as follows:</p>"
echo
echo "<pre>"
cat "$HOME/.zprofile"
echo "</pre>"

echo
echo "<h1>.zshrc Content</h1>"
echo "<p>Your ZSH Run Command file content is as follows:</p>"
echo
echo "<pre>"
cat "$HOME/.zshrc"
echo "</pre>"

echo
echo "<h1>.zlogin Content</h1>"
echo "<p>Your ZSH login file content is as follows:</p>"
echo
echo "<pre>"
cat "$HOME/.zlogin"
echo "</pre>"

echo
echo "<hr><p>Last Generated: $(date) by &copy; Conductor from <a href=\"https://thoughtasylum.com\">ThoughtAsylum</a>.</p><hr>"
echo "</body></html>"